#!flask/bin/python
from flask import Flask

port_num = 9111

app = Flask(__name__)

@app.route('/ms')
def index():
    return "Hello, World! this is micro servce 1 \n"

if __name__ == '__main__':
    app.run(host='192.168.1.3',port=port_num,debug=True)



import setuptools

#with open("README.md", "r", encoding="utf-8") as fh:
#    long_description = fh.read()

setuptools.setup(
    name="micro1", # Replace with your own username
    version="1.0.0",
    author="virenadr",
    author_email="author@example.com",
    description="A small example package",
    long_description="A long_description",
    long_description_content_type="text/markdown",
    url="",
    packages=setuptools.find_packages(),
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 2",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=2.7',
)
